@@ -324,7 +324,7 @@ def create_new_project(session):
         for i in range(num_moving):
             moving_image_name = f"{num}_MovingImage_{chr(ord('@')+i+1)}"
             moving_image_shot = session.create(
-                "MovingImage",
+                "Movingimage",
                 {
                     "name": moving_image_name,
                     "parent": moving_image_folder,
